//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Furo](index.md)/[asMentsu](as-mentsu.md)

# asMentsu

[common]\
abstract fun [asMentsu](as-mentsu.md)(): [Mentsu](../-mentsu/index.md)

获取副露的面子
